This pull request fixes #

This pull request proposes

### Changes
- [ ] This change is complete
- [ ] If you would like to list yourself as a DataLad contributor and your name is not mentioned please modify .zenodo.json file.

Please have a look @datalad/developers
